Don't forget to export .rs.dtor() for Renderscript.

BUG=5186750

Change-Id: I7e22edd906a7bf0024daf32bfb663aa430b120c9
diff --git a/lib/ExecutionEngine/Compiler.cpp b/lib/ExecutionEngine/Compiler.cpp
index 639d76e..29be79a 100644
--- a/lib/ExecutionEngine/Compiler.cpp
+++ b/lib/ExecutionEngine/Compiler.cpp
@@ -715,9 +715,10 @@
   // TODO(logan): Remove this after we have finished the
   // bccMarkExternalSymbol API.
 
   // root() and init() are born to be exported
   ExportSymbols.push_back("root");
   ExportSymbols.push_back("init");
+  ExportSymbols.push_back(".rs.dtor");
 
   // User-defined exporting symbols
   std::vector<char const *> const &UserDefinedExternalSymbols =
@@ -715,9 +715,10 @@
   // bccMarkExternalSymbol API.
 
-  // root() and init() are born to be exported
+  // root(), init(), and .rs.dtor() are born to be exported
   ExportSymbols.push_back("root");
   ExportSymbols.push_back("init");